@@ -10,19 +10,22 @@ With a row for the N most frequent values (default:10) for each column in the CS
 Since this command computes an exact frequency table, memory proportional to the
 cardinality of each column would be normally required.
 
-However, this is problematic for columns with unique values (e.g. an ID column),
+However, this is problematic for columns with ALL unique values (e.g. an ID column),
 as the command will need to load all the column's values into memory, potentially
 causing Out-of-Memory (OOM) errors for larger-than-memory datasets.
 
-To overcome this, the frequency command will automatically use the stats cache if it
-exists to get column cardinalities. This short-circuits frequency compilation for columns
-with all unique values (i.e. where rowcount == cardinality), increasing performance.
-It also has the added benefit of not having to load all the column's values into memory,
-effectively allowing the frequency command to work with larger-than-memory datasets.
+To overcome this, the frequency command can use the stats cache if it exists to get
+column cardinalities. This short-circuits frequency compilation for columns
+with all unique values (i.e. where rowcount == cardinality), eliminating the need to
+maintain a in-memory hashmap for ID columns. This allows the command to compute frequencies
+for larger-than-memory datasets.
 
-Instead, it will use the "<ALL_UNIQUE>" value for columns with all unique values.
+However, in the current implementation, the stats cache takes a while to load, eliminating
+the performance benefits of cardinality-based frequency tables.
+See https://github.com/jqnatividad/qsv/issues/2040
 
-This behavior can be adjusted with the --stats-mode option.
+Therefore, only use the `--stats-mode` option if you have a large dataset with columns
+that have all unique values and you want to avoid OOM errors.
 
 STATS_MODE "none" NOTES:
 
@@ -99,7 +102,7 @@ frequency options:
                               none: don't use cardinality information.
                                     For columns with all unique values, the first N sorted unique
                                     values (based on the --limit and --unq-limit options) will be used.
-                            [default: auto]
+                            [default: none]
    --all-unique-text <arg>  The text to use for the "<ALL_UNIQUE>" category.
                             [default: <ALL_UNIQUE>]
     -j, --jobs <arg>        The number of jobs to run in parallel.
@@ -431,6 +434,12 @@ impl Args {
         let flag_ignore_case = self.flag_ignore_case;
         let flag_no_trim = self.flag_no_trim;
 
+        // compile a vector of bool flags for all_unique_headers
+        // so we can skip the contains check in the hot loop below
+        let all_unique_flag_vec: Vec<bool> = (0..nsel_len)
+            .map(|i| all_unique_headers.contains(&i))
+            .collect();
+
         if flag_ignore_case {
             // case insensitive when computing frequencies
             let mut buf = String::new();
@@ -441,24 +450,25 @@ impl Args {
                     // safety: we know the row is not empty
                     row_buffer.clone_from(&row.unwrap());
                     for (i, field) in nsel.select(row_buffer.into_iter()).enumerate() {
-                        if all_unique_headers.contains(&i) {
+                        // safety: all_unique_flag_vec.len() is the same as nsel.len()
+                        if unsafe { *all_unique_flag_vec.get_unchecked(i) } {
                             // if the column has all unique values,
                             // we don't need to compute frequencies
                             continue;
                         }
-                        field_buffer = {
-                            if let Ok(s) = simdutf8::basic::from_utf8(field) {
-                                util::to_lowercase_into(s, &mut buf);
-                                buf.as_bytes().to_vec()
-                            } else {
-                                field.to_vec()
-                            }
-                        };
 
                         // safety: we do get_unchecked_mut on freq_tables
                         // as we know that nsel_len is the same as freq_tables.len()
                         // so we can skip the bounds check
-                        if !field_buffer.is_empty() {
+                        if !field.is_empty() {
+                            field_buffer = {
+                                if let Ok(s) = simdutf8::basic::from_utf8(field) {
+                                    util::to_lowercase_into(s, &mut buf);
+                                    buf.as_bytes().to_vec()
+                                } else {
+                                    field.to_vec()
+                                }
+                            };
                             unsafe {
                                 freq_tables.get_unchecked_mut(i).add(field_buffer);
                             }
@@ -475,22 +485,22 @@ impl Args {
                     // safety: we know the row is not empty
                     row_buffer.clone_from(&row.unwrap());
                     for (i, field) in nsel.select(row_buffer.into_iter()).enumerate() {
-                        if all_unique_headers.contains(&i) {
+                        if unsafe { *all_unique_flag_vec.get_unchecked(i) } {
                             continue;
                         }
-                        field_buffer = {
-                            if let Ok(s) = simdutf8::basic::from_utf8(field) {
-                                util::to_lowercase_into(s.trim(), &mut buf);
-                                buf.as_bytes().to_vec()
-                            } else {
-                                util::trim_bs_whitespace(field).to_vec()
-                            }
-                        };
 
                         // safety: we do get_unchecked_mut on freq_tables
                         // as we know that nsel_len is the same as freq_tables.len()
                         // so we can skip the bounds check
-                        if !field_buffer.is_empty() {
+                        if !field.is_empty() {
+                            field_buffer = {
+                                if let Ok(s) = simdutf8::basic::from_utf8(field) {
+                                    util::to_lowercase_into(s.trim(), &mut buf);
+                                    buf.as_bytes().to_vec()
+                                } else {
+                                    util::trim_bs_whitespace(field).to_vec()
+                                }
+                            };
                             unsafe {
                                 freq_tables.get_unchecked_mut(i).add(field_buffer);
                             }
@@ -511,18 +521,16 @@ impl Args {
                 if flag_no_trim {
                     // case-sensitive, don't trim whitespace
                     for (i, field) in nsel.select(row_buffer.into_iter()).enumerate() {
-                        if all_unique_headers.contains(&i) {
+                        if unsafe { *all_unique_flag_vec.get_unchecked(i) } {
                             continue;
                         }
-                        // no need to convert to string and back to bytes for a "case-sensitive"
-                        // comparison we can just use the field directly
-                        field_buffer = field.to_vec();
 
-                        // safety: we do get_unchecked_mut on freq_tables for the same safety reason
-                        // above
-                        if !field_buffer.is_empty() {
+                        // safety: get_unchecked_mut on freq_tables for same safety reason above
+                        if !field.is_empty() {
+                            // no need to convert to string and back to bytes for a "case-sensitive"
+                            // comparison we can just use the field directly
                             unsafe {
-                                freq_tables.get_unchecked_mut(i).add(field_buffer);
+                                freq_tables.get_unchecked_mut(i).add(field.to_vec());
                             }
                         } else if !flag_no_nulls {
                             unsafe {
@@ -533,20 +541,19 @@ impl Args {
                 } else {
                     // case-sensitive, trim whitespace
                     for (i, field) in nsel.select(row_buffer.into_iter()).enumerate() {
-                        if all_unique_headers.contains(&i) {
+                        if unsafe { *all_unique_flag_vec.get_unchecked(i) } {
                             continue;
                         }
-                        field_buffer = {
-                            if let Ok(s) = simdutf8::basic::from_utf8(field) {
-                                s.trim().as_bytes().to_vec()
-                            } else {
-                                util::trim_bs_whitespace(field).to_vec()
-                            }
-                        };
 
-                        // safety: we do get_unchecked_mut on freq_tables for the same safety reason
-                        // above
-                        if !field_buffer.is_empty() {
+                        // safety: get_unchecked_mut on freq_tables for same safety reason above
+                        if !field.is_empty() {
+                            field_buffer = {
+                                if let Ok(s) = simdutf8::basic::from_utf8(field) {
+                                    s.trim().as_bytes().to_vec()
+                                } else {
+                                    util::trim_bs_whitespace(field).to_vec()
+                                }
+                            };
                             unsafe {
                                 freq_tables.get_unchecked_mut(i).add(field_buffer);
                             }
