@@ -11,7 +11,6 @@
         clippy::type_complexity,
         clippy::zero_prefixed_literal,
         // correctly used
-        clippy::derive_partial_eq_without_eq,
         clippy::enum_glob_use,
         clippy::result_unit_err,
         // not practical
@@ -95,6 +94,7 @@ fn main() -> QsvExitCode {
     enabled_commands.push_str(
         "    behead      Drop header from CSV file
     cat         Concatenate by row or column
+    clipboard   Provide input from clipboard or output to clipboard
     count       Count records
     datefmt     Format date/datetime strings
     dedup       Remove redundant rows
@@ -122,8 +122,7 @@ fn main() -> QsvExitCode {
     );
 
     #[cfg(all(feature = "foreach", feature = "feature_capable"))]
-    enabled_commands
-        .push_str("    foreach     Loop over a CSV file to execute bash commands (*nix only)\n");
+    enabled_commands.push_str("    foreach     Loop over a CSV file to execute bash commands\n");
 
     enabled_commands.push_str("    frequency   Show frequency tables\n");
 
@@ -142,13 +141,17 @@ fn main() -> QsvExitCode {
     #[cfg(all(feature = "polars", feature = "feature_capable"))]
     enabled_commands.push_str("    joinp       Join CSV files using the Pola.rs engine\n");
 
-    enabled_commands.push_str("    jsonl       Convert newline-delimited JSON files to CSV\n");
+    enabled_commands.push_str(
+        "    json        Convert JSON to CSV
+    jsonl       Convert newline-delimited JSON files to CSV\n",
+    );
 
     #[cfg(all(feature = "luau", feature = "feature_capable"))]
     enabled_commands.push_str("    luau        Execute Luau script on CSV data\n");
 
     enabled_commands.push_str(
         "    partition   Partition CSV data based on a column value
+    prompt      Open a file dialog to pick a file
     pseudo      Pseudonymise the values of a column\n",
     );
 
@@ -323,6 +326,7 @@ enum Command {
     Apply,
     Behead,
     Cat,
+    Clipboard,
     Count,
     Datefmt,
     Dedup,
@@ -342,7 +346,7 @@ enum Command {
     FixLengths,
     Flatten,
     Fmt,
-    #[cfg(all(feature = "foreach", target_family = "unix", not(feature = "lite")))]
+    #[cfg(all(feature = "foreach", not(feature = "lite")))]
     ForEach,
     Frequency,
     #[cfg(all(feature = "geocode", feature = "feature_capable"))]
@@ -354,10 +358,12 @@ enum Command {
     Join,
     #[cfg(all(feature = "polars", feature = "feature_capable"))]
     JoinP,
+    Json,
     Jsonl,
     #[cfg(all(feature = "luau", feature = "feature_capable"))]
     Luau,
     Partition,
+    Prompt,
     Pseudo,
     #[cfg(all(feature = "python", feature = "feature_capable"))]
     Py,
@@ -407,6 +413,7 @@ impl Command {
             #[cfg(all(feature = "apply", feature = "feature_capable"))]
             Command::Apply => cmd::apply::run(argv),
             Command::Cat => cmd::cat::run(argv),
+            Command::Clipboard => cmd::clipboard::run(argv),
             Command::Count => cmd::count::run(argv),
             Command::Datefmt => cmd::datefmt::run(argv),
             Command::Dedup => cmd::dedup::run(argv),
@@ -422,7 +429,7 @@ impl Command {
             Command::Fetch => cmd::fetch::run(argv),
             #[cfg(all(feature = "fetch", feature = "feature_capable"))]
             Command::FetchPost => cmd::fetchpost::run(argv),
-            #[cfg(all(feature = "foreach", target_family = "unix", not(feature = "lite")))]
+            #[cfg(all(feature = "foreach", not(feature = "lite")))]
             Command::ForEach => cmd::foreach::run(argv),
             Command::Fill => cmd::fill::run(argv),
             Command::FixLengths => cmd::fixlengths::run(argv),
@@ -442,10 +449,12 @@ impl Command {
             Command::Join => cmd::join::run(argv),
             #[cfg(all(feature = "polars", feature = "feature_capable"))]
             Command::JoinP => cmd::joinp::run(argv),
+            Command::Json => cmd::json::run(argv),
             Command::Jsonl => cmd::jsonl::run(argv),
             #[cfg(all(feature = "luau", feature = "feature_capable"))]
             Command::Luau => cmd::luau::run(argv),
             Command::Partition => cmd::partition::run(argv),
+            Command::Prompt => cmd::prompt::run(argv),
             Command::Pseudo => cmd::pseudo::run(argv),
             #[cfg(all(feature = "python", feature = "feature_capable"))]
             Command::Py => cmd::python::run(argv),
