@@ -21,6 +21,7 @@ macro_rules! command_list {
         "
     behead      Drop header from CSV file
     cat         Concatenate by row or column
+    clipboard   Provide input from clipboard or output to clipboard
     count       Count records
     datefmt     Format date/datetime columns
     dedup       Remove redundant rows
@@ -42,8 +43,10 @@ macro_rules! command_list {
     index       Create CSV index for faster access
     input       Read CSVs w/ special quoting, skipping, trimming & transcoding rules
     join        Join CSV files
+    json        Convert JSON to CSV
     jsonl       Convert newline-delimited JSON files to CSV
     partition   Partition CSV data based on a column value
+    prompt      Open a file dialog to pick a file
     pseudo      Pseudonymise the values of a column
     rename      Rename the columns of CSV data efficiently
     replace     Replace patterns in CSV data
@@ -224,6 +227,7 @@ Please choose one of the following commands:",
 enum Command {
     Behead,
     Cat,
+    Clipboard,
     Count,
     Datefmt,
     Dedup,
@@ -245,8 +249,10 @@ enum Command {
     Index,
     Input,
     Join,
+    Json,
     Jsonl,
     Partition,
+    Prompt,
     Pseudo,
     Rename,
     Replace,
@@ -287,6 +293,7 @@ impl Command {
         match self {
             Command::Behead => cmd::behead::run(argv),
             Command::Cat => cmd::cat::run(argv),
+            Command::Clipboard => cmd::clipboard::run(argv),
             Command::Count => cmd::count::run(argv),
             Command::Datefmt => cmd::datefmt::run(argv),
             Command::Dedup => cmd::dedup::run(argv),
@@ -312,8 +319,10 @@ impl Command {
             Command::Index => cmd::index::run(argv),
             Command::Input => cmd::input::run(argv),
             Command::Join => cmd::join::run(argv),
+            Command::Json => cmd::json::run(argv),
             Command::Jsonl => cmd::jsonl::run(argv),
             Command::Partition => cmd::partition::run(argv),
+            Command::Prompt => cmd::prompt::run(argv),
             Command::Pseudo => cmd::pseudo::run(argv),
             Command::Rename => cmd::rename::run(argv),
             Command::Replace => cmd::replace::run(argv),
