@@ -1,5 +1,7 @@
 #[cfg(any(feature = "feature_capable", feature = "lite"))]
 use std::borrow::Cow;
+#[cfg(any(feature = "feature_capable", feature = "lite"))]
+use std::io::BufRead;
 use std::{
     cmp::min,
     env, fs,
@@ -11,10 +13,12 @@ use std::{
     time::SystemTime,
 };
 
+use ahash::AHashMap;
+use csv::ByteRecord;
 use docopt::Docopt;
 #[cfg(any(feature = "feature_capable", feature = "lite"))]
 use indicatif::{HumanCount, ProgressBar, ProgressDrawTarget, ProgressStyle};
-use log::log_enabled;
+use log::{info, log_enabled, warn};
 use reqwest::Client;
 use serde::de::DeserializeOwned;
 #[cfg(any(feature = "feature_capable", feature = "lite"))]
@@ -25,7 +29,8 @@ use sysinfo::System;
 use crate::cmd::count::polars_count_input;
 use crate::{
     config,
-    config::{Config, Delimiter, DEFAULT_WTR_BUFFER_CAPACITY},
+    config::{Config, Delimiter, DEFAULT_RDR_BUFFER_CAPACITY, DEFAULT_WTR_BUFFER_CAPACITY},
+    select::SelectColumns,
     CliError, CliResult, CURRENT_COMMAND,
 };
 
@@ -33,7 +38,7 @@ use crate::{
 macro_rules! regex_oncelock {
     ($re:literal $(,)?) => {{
         static RE: std::sync::OnceLock<regex::Regex> = std::sync::OnceLock::new();
-        RE.get_or_init(|| regex::Regex::new($re).unwrap())
+        RE.get_or_init(|| regex::Regex::new($re).expect("Invalid regex"))
     }};
 }
 
@@ -44,6 +49,32 @@ static ROW_COUNT: OnceLock<Option<u64>> = OnceLock::new();
 
 pub type ByteString = Vec<u8>;
 
+#[derive(Clone, Copy, PartialEq, Eq)]
+pub enum StatsMode {
+    Schema,
+    Frequency,
+    FrequencyForceStats,
+    None,
+}
+
+#[allow(dead_code)]
+#[derive(serde::Deserialize, Clone)]
+pub struct SchemaArgs {
+    pub flag_enum_threshold:  usize,
+    pub flag_ignore_case:     bool,
+    pub flag_strict_dates:    bool,
+    pub flag_pattern_columns: SelectColumns,
+    pub flag_dates_whitelist: String,
+    pub flag_prefer_dmy:      bool,
+    pub flag_force:           bool,
+    pub flag_stdout:          bool,
+    pub flag_jobs:            Option<usize>,
+    pub flag_no_headers:      bool,
+    pub flag_delimiter:       Option<Delimiter>,
+    pub arg_input:            Option<String>,
+    pub flag_memcheck:        bool,
+}
+
 #[inline]
 pub fn num_cpus() -> usize {
     num_cpus::get()
@@ -372,6 +403,15 @@ pub fn count_rows_regular(conf: &Config) -> Result<u64, CliError> {
     }
 }
 
+#[cfg(any(feature = "feature_capable", feature = "lite"))]
+pub fn count_lines_in_file(file: &str) -> Result<u64, CliError> {
+    let file = File::open(file)?;
+    let reader = BufReader::new(file);
+
+    let line_count = reader.lines().count() as u64;
+    Ok(line_count)
+}
+
 #[cfg(any(feature = "feature_capable", feature = "lite"))]
 pub fn prep_progress(progress: &ProgressBar, record_count: u64) {
     progress.set_style(
@@ -895,8 +935,8 @@ Self-update only works with prebuilt binaries released on GitHub https://github.
 }
 
 #[cfg(not(feature = "self_update"))]
-pub const fn qsv_check_for_update(_check_only: bool, _no_confirm: bool) -> Result<bool, String> {
-    Ok(true)
+pub fn qsv_check_for_update(_check_only: bool, _no_confirm: bool) -> Result<bool, String> {
+    Err("Self-update is disabled in this build.".to_string())
 }
 
 // the qsv hwsurvey allows us to keep a better
@@ -967,6 +1007,7 @@ fn send_hwsurvey(
             .brotli(true)
             .gzip(true)
             .deflate(true)
+            .zstd(true)
             .use_rustls_tls()
             .http2_adaptive_window(true)
             .build()
@@ -1000,12 +1041,11 @@ fn send_hwsurvey(
     }
 }
 
-#[allow(clippy::needless_pass_by_value)]
 pub fn safe_header_names(
     headers: &csv::StringRecord,
     check_first_char: bool,
     conditional: bool,
-    reserved_names: Option<Vec<String>>,
+    reserved_names: &Option<Vec<String>>,
     unsafe_prefix: &str,
     keep_case: bool,
 ) -> (Vec<String>, u16) {
@@ -1364,7 +1404,7 @@ pub fn decompress_snappy_file(
     let file_stem = Path::new(&path).file_stem().unwrap().to_str().unwrap();
     let decompressed_filepath = tmpdir
         .path()
-        .join(format!("qsv__{file_stem}__qsv_temp_decompressed"));
+        .join(format!("qsv_temp_decompressed__{file_stem}"));
     let mut decompressed_file = std::fs::File::create(decompressed_filepath.clone())?;
     std::io::copy(&mut snappy_reader, &mut decompressed_file)?;
     decompressed_file.flush()?;
@@ -1399,6 +1439,7 @@ pub async fn download_file(
         .brotli(true)
         .gzip(true)
         .deflate(true)
+        .zstd(true)
         .use_rustls_tls()
         .http2_adaptive_window(true)
         .connection_verbose(log_enabled!(log::Level::Debug) || log_enabled!(log::Level::Trace))
@@ -1529,16 +1570,17 @@ pub fn process_input(
 
     // if the input is empty or "-", its stdin. try to copy stdin to a file named
     // "stdin" in the passed temp directory
-    if arg_input.is_empty() || arg_input[0] == PathBuf::from("-") {
+    if arg_input.len() == 1 && arg_input[0] == PathBuf::from("-") {
+        // its "-", remove the "-" from the input so its empty
+        arg_input.remove(0);
+    }
+    if arg_input.is_empty() {
         // copy stdin to a file named stdin in a temp directory
         let tmp_filename = tmpdir.path().join("stdin");
         let mut tmp_file = std::fs::File::create(&tmp_filename)?;
         std::io::copy(&mut std::io::stdin(), &mut tmp_file)?;
         tmp_file.flush()?;
         processed_input.push(tmp_filename);
-        // remove the "-" from the input
-        // if the input was empty, this does nothing
-        arg_input.remove(0);
     }
 
     let work_input = if arg_input.len() == 1 {
@@ -1717,6 +1759,8 @@ pub fn write_json(
         .map(|(col_idx, b)| {
             if no_headers {
                 col_idx.to_string()
+            } else if let Ok(val) = simdutf8::basic::from_utf8(b) {
+                val.to_owned()
             } else {
                 String::from_utf8_lossy(b).to_string()
             }
@@ -1741,11 +1785,11 @@ pub fn write_json(
         }
         write!(json_wtr, "{{")?;
         for (idx, b) in record.iter().enumerate() {
-            if let Ok(val) = simdutf8::basic::from_utf8(b) {
-                temp_val = val.to_owned();
+            temp_val = if let Ok(val) = simdutf8::basic::from_utf8(b) {
+                val.to_owned()
             } else {
-                temp_val = String::from_utf8_lossy(b).to_string();
-            }
+                String::from_utf8_lossy(b).to_string()
+            };
             if temp_val.is_empty() {
                 temp_val.clone_from(&null_val);
             } else {
@@ -1858,6 +1902,221 @@ pub fn write_json_record<W: std::io::Write>(
     Ok(write!(json_wtr, "}}")?)
 }
 
+/// trim leading and trailing whitespace from a byte slice
+pub fn trim_bs_whitespace(bytes: &[u8]) -> &[u8] {
+    #[allow(clippy::unnecessary_lazy_evaluations)]
+    let start = bytes
+        .iter()
+        .position(|&b| !b.is_ascii_whitespace())
+        .unwrap_or_else(|| bytes.len());
+    let end = bytes
+        .iter()
+        .rposition(|&b| !b.is_ascii_whitespace())
+        .map_or_else(|| start, |pos| pos + 1);
+
+    &bytes[start..end]
+}
+
+// get stats records from stats.bin file, or if its invalid, by running the stats command
+/// returns tuple (`csv_fields`, `csv_stats`, `stats_col_index_map`)
+pub fn get_stats_records(
+    args: &SchemaArgs,
+    mode: StatsMode,
+) -> CliResult<(
+    ByteRecord,
+    Vec<crate::cmd::stats::Stats>,
+    AHashMap<String, usize>,
+)> {
+    let stats_args = crate::cmd::stats::Args {
+        arg_input:            args.arg_input.clone(),
+        flag_select:          crate::select::SelectColumns::parse("").unwrap(),
+        flag_everything:      false,
+        flag_typesonly:       false,
+        flag_infer_boolean:   false,
+        flag_mode:            false,
+        flag_cardinality:     true,
+        flag_median:          false,
+        flag_quartiles:       false,
+        flag_mad:             false,
+        flag_nulls:           false,
+        flag_round:           4,
+        flag_infer_dates:     true,
+        flag_dates_whitelist: args.flag_dates_whitelist.to_string(),
+        flag_prefer_dmy:      args.flag_prefer_dmy,
+        flag_force:           args.flag_force,
+        flag_jobs:            Some(njobs(args.flag_jobs)),
+        flag_stats_binout:    true,
+        flag_cache_threshold: 1, // force the creation of stats cache files
+        flag_output:          None,
+        flag_no_headers:      args.flag_no_headers,
+        flag_delimiter:       args.flag_delimiter,
+        flag_memcheck:        args.flag_memcheck,
+    };
+
+    let canonical_input_path = Path::new(&args.arg_input.clone().unwrap()).canonicalize()?;
+    let stats_binary_encoded_path = canonical_input_path.with_extension("stats.csv.bin.sz");
+
+    let stats_bin_current = if stats_binary_encoded_path.exists() {
+        let stats_bin_metadata = std::fs::metadata(&stats_binary_encoded_path)?;
+
+        let input_metadata = std::fs::metadata(args.arg_input.clone().unwrap())?;
+
+        if stats_bin_metadata.modified()? > input_metadata.modified()? {
+            info!("Valid stats.csv.bin.sz file found!");
+            true
+        } else {
+            info!("stats.csv.bin.sz file is older than input file. Regenerating stats.bin file.");
+            false
+        }
+    } else {
+        info!("stats.csv.bin.sz file does not exist: {stats_binary_encoded_path:?}");
+        false
+    };
+
+    if mode == StatsMode::None || (mode == StatsMode::Frequency && !stats_bin_current) {
+        // if the stats.bin file is not present, we're just doing frequency old school
+        // without cardinality
+        return Ok((ByteRecord::new(), Vec::new(), AHashMap::new()));
+    }
+
+    let mut stats_bin_loaded = false;
+
+    // if stats.bin file exists and is current, use it
+    let mut csv_stats: Vec<crate::cmd::stats::Stats> = Vec::new();
+
+    if stats_bin_current && !args.flag_force {
+        let bin_file = BufReader::with_capacity(
+            DEFAULT_RDR_BUFFER_CAPACITY * 4,
+            File::open(stats_binary_encoded_path)?,
+        );
+        let mut buf_binsz_decoder = snap::read::FrameDecoder::new(bin_file);
+        match bincode::deserialize_from(&mut buf_binsz_decoder) {
+            Ok(stats) => {
+                csv_stats = stats;
+                stats_bin_loaded = true;
+            },
+            Err(e) => {
+                wwarn!(
+                    "Error reading stats.csv.bin.sz file: {e:?}. Regenerating stats.bin.sz file."
+                );
+            },
+        }
+    }
+
+    if !stats_bin_loaded {
+        // otherwise, run stats command to generate stats.csv.bin.sz file
+        let tempfile = tempfile::Builder::new()
+            .suffix(".stats.csv")
+            .tempfile()
+            .unwrap();
+        let tempfile_path = tempfile.path().to_str().unwrap().to_string();
+
+        let statsbin_path = canonical_input_path.with_extension("stats.csv.bin.sz");
+
+        let mut stats_args_str = if mode == StatsMode::Schema {
+            // mode is GetStatsMode::Schema
+            // we're generating schema, so we need all the stats
+            format!(
+                "stats {input} --infer-dates --dates-whitelist {dates_whitelist} --round 4 \
+                 --cardinality --output {output} --stats-binout --force",
+                input = {
+                    if let Some(arg_input) = stats_args.arg_input.clone() {
+                        arg_input
+                    } else {
+                        "-".to_string()
+                    }
+                },
+                dates_whitelist = stats_args.flag_dates_whitelist,
+                output = tempfile_path,
+            )
+        } else {
+            // mode is GetStatsMode::Frequency or GetStatsMode::FrequencyForceStats
+            // we're doing frequency, so we just need cardinality
+            format!(
+                "stats {input} --cardinality --stats-binout --output {output}",
+                input = {
+                    if let Some(arg_input) = stats_args.arg_input.clone() {
+                        arg_input
+                    } else {
+                        "-".to_string()
+                    }
+                },
+                output = tempfile_path,
+            )
+        };
+        if args.flag_prefer_dmy {
+            stats_args_str = format!("{stats_args_str} --prefer-dmy");
+        }
+        if args.flag_no_headers {
+            stats_args_str = format!("{stats_args_str} --no-headers");
+        }
+        if let Some(delimiter) = args.flag_delimiter {
+            let delim = delimiter.as_byte() as char;
+            stats_args_str = format!("{stats_args_str} --delimiter {delim}");
+        }
+        if args.flag_memcheck {
+            stats_args_str = format!("{stats_args_str} --memcheck");
+        }
+        if let Some(mut jobs) = stats_args.flag_jobs {
+            if jobs > 2 {
+                jobs -= 1; // leave one core for the main thread
+            }
+            stats_args_str = format!("{stats_args_str} --jobs {jobs}");
+        }
+
+        let stats_args_vec: Vec<&str> = stats_args_str.split_whitespace().collect();
+
+        let qsv_bin = std::env::current_exe().unwrap();
+        let mut stats_cmd = std::process::Command::new(qsv_bin);
+        stats_cmd.args(stats_args_vec);
+        let _stats_output = stats_cmd.output()?;
+
+        let bin_file =
+            BufReader::with_capacity(DEFAULT_RDR_BUFFER_CAPACITY * 2, File::open(statsbin_path)?);
+        let mut buf_binsz_decoder = snap::read::FrameDecoder::new(bin_file);
+
+        match bincode::deserialize_from(&mut buf_binsz_decoder) {
+            Ok(stats) => {
+                csv_stats = stats;
+            },
+            Err(e) => {
+                return fail_clierror!(
+                    "Error reading stats.csv.bin.sz file: {e:?}. Schema generation aborted."
+                );
+            },
+        }
+    };
+
+    // get the headers from the input file
+    let mut rdr = csv::Reader::from_path(args.arg_input.clone().unwrap()).unwrap();
+    let csv_fields = rdr.byte_headers()?.clone();
+    drop(rdr);
+
+    let stats_columns = if stats_bin_loaded {
+        // if stats.bin file is loaded, we need to get the headers from the stats.csv file
+        let stats_bin_csv_path = canonical_input_path.with_extension("stats.csv");
+        let mut stats_csv_reader = csv::Reader::from_path(stats_bin_csv_path)?;
+        let stats_csv_headers = stats_csv_reader.headers()?.clone();
+        drop(stats_csv_reader);
+        stats_csv_headers
+    } else {
+        // otherwise, we generate the headers from the stats_args struct
+        // as we used the stats_args struct to generate the stats.csv file
+        stats_args.stat_headers()
+    };
+
+    let mut stats_col_index_map = AHashMap::new();
+
+    for (i, col) in stats_columns.iter().enumerate() {
+        if col != "field" {
+            // need offset by 1 due to extra "field" column in headers that's not in stats records
+            stats_col_index_map.insert(col.to_owned(), i - 1);
+        }
+    }
+
+    Ok((csv_fields, csv_stats, stats_col_index_map))
+}
+
 // comment out for now as this is still WIP
 // pub fn create_json_record(
 //     no_headers: bool,
