@@ -30,6 +30,7 @@ macro_rules! rassert_eq {
 
 mod workdir;
 
+mod test_100;
 #[cfg(feature = "apply")]
 mod test_apply;
 #[cfg(feature = "datapusher_plus")]
@@ -38,6 +39,8 @@ mod test_applydp;
 mod test_behead;
 #[cfg(any(feature = "feature_capable", feature = "lite"))]
 mod test_cat;
+#[cfg(any(feature = "feature_capable", feature = "lite"))]
+mod test_clipboard;
 mod test_combos;
 mod test_comments;
 mod test_count;
@@ -64,7 +67,7 @@ mod test_fixlengths;
 mod test_flatten;
 #[cfg(any(feature = "feature_capable", feature = "lite"))]
 mod test_fmt;
-#[cfg(all(feature = "foreach", target_family = "unix"))]
+#[cfg(all(feature = "foreach"))]
 mod test_foreach;
 mod test_frequency;
 #[cfg(all(feature = "feature_capable", feature = "geocode"))]
@@ -76,12 +79,15 @@ mod test_input;
 mod test_join;
 #[cfg(feature = "polars")]
 mod test_joinp;
+#[cfg(not(feature = "datapusher_plus"))]
+mod test_json;
 #[cfg(any(feature = "feature_capable", feature = "lite"))]
 mod test_jsonl;
 #[cfg(feature = "luau")]
 mod test_luau;
 #[cfg(any(feature = "feature_capable", feature = "lite"))]
 mod test_partition;
+mod test_prompt;
 mod test_pseudo;
 #[cfg(feature = "python")]
 mod test_py;
